==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AssigningSeriesStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HighlightingInfoDescriptionMetadata } from "./HighlightingInfoDescriptionMetadata";
/**
 * @hidden
 */
var AssigningSeriesStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningSeriesStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningSeriesStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
        HighlightingInfoDescriptionMetadata.d(a);
    };
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        a.item("StartIndex", "Number:int");
        a.item("EndIndex", "Number:int");
        a.item("StartDate", "Date");
        a.item("EndDate", "Date");
        a.item("GetItemsRef", "(w:GetItems,wf:GetItems)MethodRef");
        a.item("Fill", "Brush");
        a.item("Stroke", "Brush");
        a.item("Opacity", "Number:double");
        a.item("FadeOpacity", "Number:double");
        a.item("HighlightingInfo", "ExportedType:HighlightingInfo");
        a.item("MaxAllSeriesHighlightingProgress", "Number:double");
        a.item("SumAllSeriesHighlightingProgress", "Number:double");
        a.item("TotalAllSeriesHighlightingProgress", "Number:double");
        a.item("HighlightingHandled", "Boolean");
        a.item("HasDateRange", "Boolean");
        a.item("IsNegativeShape", "Boolean");
        a.item("IsThumbnail", "Boolean");
    };
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningSeriesStyleEventArgsBase", AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningSeriesStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningSeriesStyleEventArgsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningSeriesStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HighlightingInfoDescriptionMetadata } from "./HighlightingInfoDescriptionMetadata";
/**
 * @hidden
 */
var AssigningSeriesStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningSeriesStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningSeriesStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.k(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
        HighlightingInfoDescriptionMetadata.d(a);
    };
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        a.item("StartIndex", "Number:int");
        a.item("EndIndex", "Number:int");
        a.item("StartDate", "Date");
        a.item("EndDate", "Date");
        a.item("GetItemsRef", "(w:GetItems,wf:GetItems)MethodRef");
        a.item("Fill", "Brush");
        a.item("Stroke", "Brush");
        a.item("Opacity", "Number:double");
        a.item("FadeOpacity", "Number:double");
        a.item("HighlightingInfo", "ExportedType:HighlightingInfo");
        a.item("MaxAllSeriesHighlightingProgress", "Number:double");
        a.item("SumAllSeriesHighlightingProgress", "Number:double");
        a.item("TotalAllSeriesHighlightingProgress", "Number:double");
        a.item("HighlightingHandled", "Boolean");
        a.item("HasDateRange", "Boolean");
        a.item("IsNegativeShape", "Boolean");
        a.item("IsThumbnail", "Boolean");
    };
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.b(a);
        a.ab("AssigningSeriesStyleEventArgsBase", AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningSeriesStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningSeriesStyleEventArgsBaseDescriptionMetadata };
